# glowprom

![Docker Image Version (latest semver)](https://img.shields.io/docker/v/andrewjw/glowprom)
[![Coverage Status](https://coveralls.io/repos/github/andrewjw/glowprom/badge.svg?branch=master)](https://coveralls.io/github/andrewjw/glowprom?branch=master)

Receives gas and electric meter data from https://glowmarkt.com/ and exposes it to Prometheus.

